@@ -14,7 +14,7 @@ use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 =head1 NAME
 
@@ -133,6 +133,20 @@ has credentials => (
 
 =item *
 
+C<auth>
+
+    auth => 'basic'
+
+The authentication method to use.
+
+=cut
+
+has auth => (
+    is => 'ro',
+);
+
+=item *
+
 C<post_data>
 
     post_data => ['A string','across multiple','scalars']
@@ -176,6 +190,20 @@ has timeout => (
 
 =item *
 
+C<unix_socket>
+
+    unix_socket => '/var/run/docker/docker.sock'
+
+The timeout for the request
+
+=cut
+
+has unix_socket => (
+    is => 'ro',
+);
+
+=item *
+
 C<form_args>
 
 The HTML form parameters. These get converted into
@@ -825,7 +853,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2018-2021 by Max Maischein C<corion@cpan.org>.
+Copyright 2018-2022 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
